# -*- coding: utf-8 -*-
#
#  DuedilApiClient
#  @copyright 2014 Christian Ledermann
#
#  Licensed under the Apache License, Version 2.0 (the "License"); you may
#  not use this file except in compliance with the License. You may obtain
#  a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#  License for the specific language governing permissions and limitations
#  under the License.
#

"""
Python `Duedil API <https://developer.duedil.com/>`_ Wrapper, written to access the v3 API.

Lets you interact easily with Duedil directly from your Python code. The project is
hosted on `Github <https://github.com/founders4schools/duedilv3>`_ and is referenced on
`PyPI <https://pypi.python.org/pypi/duedil>`_.

Installation
------------

As all PyPI hosted package, installation is very simple, just run::

    sudo pip install duedil

"""
