# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from ... import (Resource)


class Keywords(Resource):

    attribute_names = [
        'locale',
        'name',
        'keywords',
        'company_url',
    ]
